@@ -191,7 +191,7 @@ class ModelInstance:
         self.model_id = model_id
         print('START CHAT HISTORY DEBUGGING')
         self.chat_history = []
-        self.chat_history = self.get_chat_history()
+        self.get_chat_history()
         print(self.chat_history)
         print('END CHAT HISTORY DEBUGGING')
         self.is_deployed = self.instance_id is not None
